@@ -114,8 +114,12 @@ def export_component_screen_capture(folder, component, x_dim=1000, y_dim=1000):
             pixels. (Default: 1000).
     """
     # Get the coordinates of the upper-left corner of the image from the component
-    ul_x = component.Attributes.Pivot.X - int(((x_dim / 2) - 120) / 2)
-    ul_y = component.Attributes.Pivot.Y - int(((y_dim / 2) - 120) / 2)
+    if component.Name == 'LB ImageViewer':
+        ul_x = component.Attributes.Pivot.X - int(((x_dim / 2) - 400) / 2)
+        ul_y = component.Attributes.Pivot.Y - int(((y_dim / 2) - 400) / 2)
+    else:
+        ul_x = component.Attributes.Pivot.X - int(((x_dim / 2) - 120) / 2)
+        ul_y = component.Attributes.Pivot.Y - int(((y_dim / 2) - 120) / 2)
     rect = System.Drawing.Rectangle(ul_x, ul_y, x_dim, y_dim)
 
     # set the image zoon/resolution
